@@ -41,20 +41,21 @@ import config
 import connector_provider
 import identifier_util
 import upnp_util
-import cache_manager_provider
 import subsonic_util
 import codec
 import constants
 import cache_actions
+import cache_type
+import album_util
 
 from option_key import OptionKey
 from option_util import get_option
 
 import upmplgutils
+import upmpdmeta
 
 from msgproc_provider import msgproc
 
-import secrets
 import os
 
 import persistence
@@ -183,7 +184,7 @@ def __get_track_info_list(track_list: list[Song]) -> list[TrackInfo]:
     for song in track_list:
         bit_depth: int = song.getItem().getByName(constants.ItemKey.BIT_DEPTH.value)
         sampling_rate: int = song.getItem().getByName(constants.ItemKey.SAMPLING_RATE.value)
-        suffix: int = song.getSuffix()
+        suffix: str = song.getSuffix()
         bitrate: int = song.getBitRate()
         current: TrackInfo = TrackInfo()
         current.bit_depth = bit_depth
@@ -213,7 +214,7 @@ def __get_track_list_streaming_properties(track_list: list[Song]) -> dict[str, l
         sampling_rate: int = song.getItem().getByName(constants.ItemKey.SAMPLING_RATE.value)
         __maybe_append_to_dict_list(result, __DICT_KEY_SAMPLERATE, sampling_rate)
         # suffix
-        suffix: int = song.getSuffix()
+        suffix: str = song.getSuffix()
         __maybe_append_to_dict_list(result, __DICT_KEY_SUFFIX, suffix)
         # bitrate
         bitrate: int = song.getBitRate()
@@ -289,9 +290,14 @@ def artist_entry_for_album(objid, album: Album) -> dict[str, any]:
         pid=objid,
         title=artist_entry_title))
     if artist_entry:
-        # get an album cover for the artist entry
-        art_uri: str = (art_retriever.get_artist_art_url_using_albums(artist_id=album.getArtistId())
-                        if album.getArtistId() else None)
+        art_uri: str = None
+        # does the artist has coverArt?
+        artist_cover_art: str = subsonic_util.get_artist_cover_art(artist)
+        # if not already found from the artist, we try to get an album cover for the artist entry
+        if artist_cover_art:
+            art_uri = subsonic_util.build_cover_art_url(item_id=artist_cover_art, force_save=True)
+        else:
+            art_uri = art_retriever.get_artist_art_url_using_albums_by_artist_id(artist_id=album.getArtistId())
         upnp_util.set_album_art_from_uri(album_art_uri=art_uri, target=artist_entry)
         cache_actions.on_album(album)
     return artist_entry
@@ -307,23 +313,26 @@ def get_album_quality_badge(album: Album, force_load: bool = False) -> str:
             list_identifier=album.getId())
         msgproc.log(f"get_album_quality_badge for album_id: [{album.getId()}] "
                     f"force_load: [{force_load}] -> [{quality_badge}]")
+        artist_id: str = album.getArtistId()
+        album_mbid: str = subsonic_util.get_album_musicbrainz_id(album)
+        # save
+        persistence.save_album_metadata(
+            album_metadata=persistence.AlbumMetadata(
+                album_id=album.getId(),
+                quality_badge=quality_badge,
+                album_musicbrainz_id=album_mbid,
+                album_artist_id=artist_id))
         return quality_badge
     else:
         album_metadata: persistence.AlbumMetadata = persistence.get_album_metadata(album_id=album.getId())
-        if album_metadata:
-            return album_metadata.quality_badge
-
-
-def __store_album_badge(album_id: str, quality_badge: str) -> str:
-    if album_id:
-        persistence.save_quality_badge(album_id=album_id, quality_badge=quality_badge)
-    return quality_badge
+        return album_metadata.quality_badge if album_metadata else None
 
 
 def get_track_list_badge(track_list: list[Song], list_identifier: str = None) -> str:
     quality_badge: str = __get_track_list_badge(track_list, list_identifier)
-    if quality_badge and list_identifier:
-        __store_album_badge(album_id=list_identifier, quality_badge=quality_badge)
+    if config.debug_badge_mngmt:
+        msgproc.log(f"Quality badge for id: [{list_identifier}] len: [{len(track_list) if track_list else 0}] -> "
+                    f"[{quality_badge}]")
     return quality_badge
 
 
@@ -406,7 +415,7 @@ def __get_track_list_badge(track_list: list[Song], list_identifier: str = None)
             if unique_bitrate:
                 display_codec = f"{display_codec}@{unique_bitrate}"
             return f"{display_codec}/{sr}"
-        if unique_suffix and unique_suffix in config.whitelist_codecs:
+        if unique_suffix and unique_suffix.lower() in config.whitelist_codecs:
             if best_bit_depth == 1:
                 return f"DSD {sr}"
             else:
@@ -441,7 +450,7 @@ def genre_artist_to_entry(
         objid,
         artist_name)
     if artist_id:
-        entry = artist_to_entry(
+        entry = artist_to_entry_raw(
             objid=objid,
             artist_id=artist_id,
             entry_name=artist_name)
@@ -453,6 +462,20 @@ def album_to_navigable_entry(
         album: Album,
         options: dict[str, any] = {}) -> dict[str, any]:
     title: str = album.getTitle()
+    artist_id: str = album.getArtistId()
+    album_mbid: str = subsonic_util.get_album_musicbrainz_id(album=album)
+    album_path_joined: str = album_util.get_album_path_list_joined(album=album)
+    if artist_id or album_mbid or album_path_joined:
+        # msgproc.log(f"Metadata for album_id [{album.getId()}] -> "
+        #             f"artist_id [{artist_id}] "
+        #             f"album_path_joined [{album_path_joined}] "
+        #             f"album_mb_id [{'mb' if album_mbid else ''}], persisting ...")
+        persistence.save_album_metadata(album_metadata=persistence.AlbumMetadata(
+            album_id=album.getId(),
+            album_musicbrainz_id=album_mbid,
+            album_artist_id=artist_id,
+            album_path=album_path_joined))
+    album_version: str = subsonic_util.get_album_version(album)
     # number of discs
     title = subsonic_util.append_number_of_discs_to_album_title(
         current_albumtitle=title,
@@ -464,7 +487,7 @@ def album_to_navigable_entry(
         current_albumtitle=title,
         album=album,
         config_getter=lambda: config.get_config_param_as_bool(
-            constants.ConfigParam.APPEND_TRACK_CNT_IN_ALBUM_CONTAINER))
+            constants.ConfigParam.ALLOW_APPEND_TRACK_CNT_IN_ALBUM_CONTAINER))
     # explicit?
     title = subsonic_util.append_explicit_if_needed(title, album)
     album_date_for_sorting: str = subsonic_util.get_album_date_for_sorting(album)
@@ -501,6 +524,11 @@ def album_to_navigable_entry(
         album_quality_badge=album_quality_badge,
         album_entry_type=constants.AlbumEntryType.ALBUM_CONTAINER,
         is_search_result=False)
+    title = subsonic_util.append_album_version_to_album_title(
+        current_albumtitle=title,
+        album_version=album_version,
+        album_entry_type=constants.AlbumEntryType.ALBUM_CONTAINER,
+        is_search_result=False)
     # msgproc.log(f"album_to_navigable_entry title [{title}]")
     append_artist: bool = (config.get_config_param_as_bool(
                            constants.ConfigParam.ALLOW_APPEND_ARTIST_IN_ALBUM_CONTAINER) and
@@ -508,8 +536,7 @@ def album_to_navigable_entry(
     if append_artist:
         artist: str = album.getArtist()
         if artist:
-            # title = f"{artist} - {title}"
-            title = f"{title} [{artist}]"
+            title = f"{title} - {artist}"
     entry_title: str = title
     entry_title = subsonic_util.append_album_id_to_album_title(
         current_albumtitle=entry_title,
@@ -518,24 +545,25 @@ def album_to_navigable_entry(
         is_search_result=False)
     if config.get_config_param_as_bool(constants.ConfigParam.SHOW_ALBUM_MBID_IN_ALBUM_CONTAINER):
         # available here?
-        mb_id: str = subsonic_util.get_album_musicbrainz_id(album)
-        if not mb_id:
+        album_mbid: str = subsonic_util.get_album_musicbrainz_id(album)
+        if not album_mbid:
             # see if it's available in cache
             if config.get_config_param_as_bool(constants.ConfigParam.DUMP_ACTION_ON_MB_ALBUM_CACHE):
-                msgproc.log(f"Trying to got album mb_id from cache for [{album.getId()}] ...")
-            mb_id = cache_actions.get_album_mb_id(album.getId())
+                msgproc.log(f"Trying to got album_mbid from cache for [{album.getId()}] ...")
+            album_metadata: persistence.AlbumMetadata = persistence.get_album_metadata(album_id=album.getId())
+            album_mbid = album_metadata.album_musicbrainz_id if album_metadata else None
             if config.get_config_param_as_bool(constants.ConfigParam.DUMP_ACTION_ON_MB_ALBUM_CACHE):
-                msgproc.log(f"Got album mb_id from cache for [{album.getId()}] -> [mb:{mb_id}]")
+                msgproc.log(f"Got album_mbid from cache for [{album.getId()}] -> [mb:{album_mbid}]")
         else:
             if config.get_config_param_as_bool(constants.ConfigParam.DUMP_ACTION_ON_MB_ALBUM_CACHE):
-                msgproc.log(f"Album mb_id for [{album.getId()}] -> [{mb_id}]")
+                msgproc.log(f"Album album_mbid for [{album.getId()}] -> [{album_mbid}]")
 
-        if mb_id:
+        if album_mbid:
             # we can display it!
             if config.get_config_param_as_bool(constants.ConfigParam.SHOW_ALBUM_MB_ID_AS_PLACEHOLDER):
                 entry_title = f"{entry_title} [mb]"
             else:
-                entry_title = f"{entry_title} [mb:{mb_id}]"
+                entry_title = f"{entry_title} [mb:{album_mbid}]"
     # anomalies
     show_album_genre_information(album)
     entry: dict[str, any] = upmplgutils.direntry(
@@ -543,9 +571,9 @@ def album_to_navigable_entry(
         pid=objid,
         title=entry_title,
         artist=artist)
-    if album_quality_badge:
-        upnp_util.set_metadata("albumquality", album_quality_badge, entry)
-    upnp_util.set_album_art_from_uri(connector_provider.get().buildCoverArtUrl(album.getCoverArt()), entry)
+    upnp_util.set_upmpd_meta(upmpdmeta.UpMpdMeta.ALBUM_QUALITY, album_quality_badge, entry)
+    subsonic_util.set_album_metadata(album=album, target=entry)
+    upnp_util.set_album_art_from_uri(subsonic_util.build_cover_art_url(album.getCoverArt()), entry)
     upnp_util.set_album_id(album.getId(), entry)
     if config.get_config_param_as_bool(constants.ConfigParam.SET_CLASS_TO_ALBUM_FOR_NAVIGABLE_ALBUM):
         upnp_util.set_class_album(entry)
@@ -565,45 +593,83 @@ def show_album_genre_information(album: Album):
 def genre_to_entry(
         objid,
         current_genre: Genre) -> dict[str, any]:
-    name: str = current_genre.getName()
+    genre_name: str = current_genre.getName()
     genre_art: str = None
-    genre_album_set: set[str] = cache_manager_provider.get().get_cached_element(
-        ElementType.GENRE,
-        name)
-    random_album_id: str = (secrets.choice(tuple(genre_album_set))
-                            if genre_album_set and len(genre_album_set) > 0
-                            else None)
-    if random_album_id:
-        genre_art = subsonic_util.get_album_cover_art_url_by_album_id(random_album_id)
+    genre_art_url: str = None
+    # first, try to look in kv cache
+    kv_item_for_genre: persistence.KeyValueItem = persistence.get_kv_item(
+        partition=cache_type.CacheType.GENRE_ALBUM_ART.getName(),
+        key=genre_name)
+    msgproc.log(f"genre_to_entry cache hit for [{genre_name}]: "
+                f"[{'yes' if kv_item_for_genre and kv_item_for_genre.value else 'no'}] ")
+    if kv_item_for_genre and kv_item_for_genre.value:
+        genre_art = kv_item_for_genre.value
+        genre_art_url = subsonic_util.build_cover_art_url(item_id=genre_art)
+    # msgproc.log(f"For genre [{genre_name}] cache hit [{'yes' if cached_by_genre else 'no'}]")
     if not genre_art:
         # load up to 5 albums
         res: Response[AlbumList] = connector_provider.get().getAlbumList(
             ltype=ListType.BY_GENRE,
-            genre=name,
+            genre=genre_name,
             size=5)
         if not res or not res.isOk():
-            msgproc.log(f"Cannot get albums by genre [{name}]")
+            msgproc.log(f"Cannot get albums by genre [{genre_name}]")
         album_list: AlbumList = res.getObj()
         msgproc.log(f"Loaded [{len(album_list.getAlbums()) if album_list and album_list.getAlbums() else 0}] "
-                    f"albums for genre [{name}]")
+                    f"albums for genre [{genre_name}]")
         if album_list and len(album_list.getAlbums()) > 0:
-            album: Album = secrets.choice(album_list.getAlbums())
-            genre_art = album.getCoverArt()
+            # look for one with a cover art
+            # album: Album = secrets.choice(album_list.getAlbums())
+            album: Album
+            for album in album_list.getAlbums():
+                if not album.getCoverArt():
+                    continue
+                genre_art = album.getCoverArt()
+                # store in kv cache!
+                persistence.save_key_value_item(key_value_item=persistence.KeyValueItem(
+                    partition=cache_type.CacheType.GENRE_ALBUM_ART.getName(),
+                    key=genre_name,
+                    value=genre_art))
+                genre_art_url = subsonic_util.build_cover_art_url(item_id=genre_art)
     identifier: ItemIdentifier = ItemIdentifier(
         ElementType.GENRE.getName(),
         current_genre.getName())
     id: str = identifier_util.create_objid(
         objid,
         identifier_util.create_id_from_identifier(identifier))
-    entry = upmplgutils.direntry(id, objid, name)
-    upnp_util.set_album_art_from_uri(connector_provider.get().buildCoverArtUrl(genre_art), entry)
+    entry = upmplgutils.direntry(id, objid, genre_name)
+    upnp_util.set_album_art_from_uri(genre_art_url, entry)
     return entry
 
 
 def artist_to_entry(
+        objid,
+        artist: Artist,
+        entry_name: str = None,
+        additional_identifier_properties: dict[ItemIdentifierKey, any] = {},
+        options: dict[str, any] = {}) -> dict[str, any]:
+    cover_art: str = subsonic_util.get_artist_cover_art(artist)
+    artist_roles: list[str] = subsonic_util.get_artist_roles(artist=artist)
+    msgproc.log(f"artist_to_entry artist [{artist.getId()}] [{artist.getName()}] -> "
+                f"roles [{artist_roles}] "
+                f"coverArt [{cover_art}]")
+    select_entry_name: str = entry_name if entry_name else f"{artist.getName()} [{', '.join(artist_roles)}]"
+    artist_entry: dict[str, any] = artist_to_entry_raw(
+        objid=objid,
+        artist_id=artist.getId(),
+        entry_name=select_entry_name,
+        artist_cover_art=cover_art,
+        additional_identifier_properties=additional_identifier_properties,
+        options=options)
+    subsonic_util.set_artist_metadata(artist=artist, target=artist_entry)
+    return artist_entry
+
+
+def artist_to_entry_raw(
         objid,
         artist_id: str,
         entry_name: str,
+        artist_cover_art: str = None,
         additional_identifier_properties: dict[ItemIdentifierKey, any] = {},
         options: dict[str, any] = {}) -> dict[str, any]:
     identifier: ItemIdentifier = ItemIdentifier(
@@ -616,63 +682,32 @@ def artist_to_entry(
     id: str = identifier_util.create_objid(
         objid=objid,
         id=identifier_util.create_id_from_identifier(identifier))
-    entry = upmplgutils.direntry(id, objid, entry_name)
+    entry = upmplgutils.direntry(id=id, pid=objid, title=entry_name)
     skip_art: bool = get_option(options=options, option_key=OptionKey.SKIP_ART)
-    if not skip_art and artist_id:
-        # find art
-        album_art_uri: str = get_album_art_uri_for_artist_id(artist_id)
+    album_art_uri: str = (subsonic_util.build_cover_art_url(artist_cover_art)
+                          if artist_cover_art is not None
+                          else None)
+    if not album_art_uri and (not skip_art and artist_id):
+        # first we try in the cache ...
+        artist_metadata: persistence.ArtistMetadata = persistence.get_artist_metadata(artist_id=artist_id)
+        if artist_metadata and artist_metadata.artist_cover_art:
+            album_art_uri = subsonic_util.build_cover_art_url(item_id=artist_metadata.artist_cover_art)
+            # msgproc.log(f"artist_to_entry_raw found cached cover_art for artist_id [{artist_id}] -> "
+            #             f"[{artist_metadata.artist_cover_art}]")
+        else:
+            # find art from albums
+            album_art_uri = art_retriever.get_album_art_uri_for_artist_id(artist_id)
+    if album_art_uri:
         upnp_util.set_album_art_from_uri(
             album_art_uri=album_art_uri,
             target=entry)
     upnp_util.set_class_artist(entry)
+    subsonic_util.set_artist_metadata_by_artist_id(
+        artist_id=artist_id,
+        target=entry)
     return entry
 
 
-def get_album_art_uri_for_artist_id(artist_id: str) -> str:
-    art_album_id: str = cache_actions.get_album_id_by_artist_id(artist_id=artist_id)
-    if art_album_id:
-        msgproc.log(f"artist_to_entry cache hit for [{artist_id}] -> [{art_album_id}]")
-        art_album: Album = subsonic_util.try_get_album(art_album_id)
-        if not art_album:
-            # delete offending album from cache
-            cache_actions.delete_album_by_artist_id(artist_id)
-        art_album_cover_art_uri: str = (connector_provider.get().buildCoverArtUrl(art_album.getCoverArt())
-                                        if art_album
-                                        else None)
-        return art_album_cover_art_uri
-    else:
-        msgproc.log(f"artist_to_entry loading artist by id [{artist_id}] ...")
-        # load artist
-        try:
-            res: Response[Artist] = connector_provider.get().getArtist(artist_id=artist_id)
-            artist: Artist = res.getObj() if res and res.isOk() else None
-            album_list: list[Album] = artist.getAlbumList() if artist else []
-            select_album_list: list[Album] = album_list
-            # try to avoid "appearances" first
-            as_main_artist_album_list: list[Album] = subsonic_util.get_artist_albums_as_appears_on(
-                artist_id=artist_id,
-                album_list=album_list,
-                opposite=True)
-            msgproc.log(f"artist_to_entry select_album_list for [{artist_id}] "
-                        f"[{artist.getName() if artist else None}] "
-                        f"full length [{len(album_list) if album_list else 0}] "
-                        f"as main artist only [{len(as_main_artist_album_list)}]")
-            if len(as_main_artist_album_list) > 0:
-                select_album_list = as_main_artist_album_list
-            select_album: Album = (secrets.choice(select_album_list)
-                                   if select_album_list and len(select_album_list) > 0
-                                   else None)
-            if select_album:
-                cache_actions.on_album_for_artist_id(artist_id=artist_id, album=select_album)
-                cache_actions.on_album(album=select_album)
-            album_art_uri: str = (connector_provider.get().buildCoverArtUrl(select_album.getCoverArt())
-                                  if select_album
-                                  else None)
-            return album_art_uri
-        except Exception as ex:
-            msgproc.log(f"artist_to_entry cannot load artist [{artist_id}] [{type(ex)}] [{ex}]")
-
-
 def artist_initial_to_entry(
         objid,
         artist_initial: str,
@@ -704,6 +739,7 @@ def build_intermediate_url(track_id: str) -> str:
 def song_to_entry(
         objid,
         song: Song,
+        force_cover_art_save: bool = False,
         options: dict[str, any] = {}) -> dict:
     entry = {}
     identifier: ItemIdentifier = ItemIdentifier(ElementType.TRACK.getName(), song.getId())
@@ -717,7 +753,7 @@ def song_to_entry(
     multi_codec_album: MultiCodecAlbum = get_option(options=options, option_key=OptionKey.MULTI_CODEC_ALBUM)
     if (MultiCodecAlbum.YES == multi_codec_album and
         config.allow_blacklisted_codec_in_song == 1 and
-            (not song.getSuffix() in config.whitelist_codecs)):
+            (not song.getSuffix().lower() in config.whitelist_codecs)):
         title = "{} [{}]".format(title, song.getSuffix())
     upnp_util.set_album_title(title, entry)
     entry['tp'] = 'it'
@@ -731,9 +767,7 @@ def song_to_entry(
     entry['upnp:album'] = song.getAlbum()
     entry['upnp:genre'] = song.getGenre()
     entry['res:mime'] = song.getContentType()
-    # prefer album for cover art
-    # album_art_uri: str = connector_provider.get().buildCoverArtUrl(album_id if album_id else song.getId())
-    album_art_uri: str = connector_provider.get().buildCoverArtUrl(song.getCoverArt())
+    album_art_uri: str = subsonic_util.build_cover_art_url(item_id=song.getCoverArt(), force_save=force_cover_art_save)
     upnp_util.set_album_art_from_uri(album_art_uri=album_art_uri, target=entry)
     entry['duration'] = str(song.getDuration())
     # channel count, bit depth, sample rate and bit rate
@@ -759,6 +793,7 @@ def song_to_entry(
                     f"channelCount [{cc}] "
                     f"mimetype [{song.getContentType()}] "
                     f"duration [{song.getDuration()}]")
+    subsonic_util.set_song_metadata(song=song, target=entry)
     return entry
 
 
@@ -770,7 +805,7 @@ def playlist_to_entry(
         playlist.getId())
     id: str = identifier_util.create_objid(objid, identifier_util.create_id_from_identifier(identifier))
     entry = upmplgutils.direntry(id, objid, playlist.getName())
-    art_uri: str = (connector_provider.get().buildCoverArtUrl(playlist.getCoverArt())
+    art_uri: str = (subsonic_util.build_cover_art_url(playlist.getCoverArt())
                     if playlist.getCoverArt() else None)
     upnp_util.set_album_art_from_uri(album_art_uri=art_uri, target=entry)
     return entry
@@ -780,7 +815,7 @@ def get_allow_disc_count_in_album_entry(is_search_result: bool) -> bool:
     if is_search_result:
         return config.get_config_param_as_bool(constants.ConfigParam.ALLOW_APPEND_DISC_CNT_IN_ALBUM_SEARCH_RESULT)
     else:
-        return config.get_config_param_as_bool(constants.ConfigParam.APPEND_DISC_CNT_IN_ALBUM_VIEW)
+        return config.get_config_param_as_bool(constants.ConfigParam.ALLOW_APPEND_DISC_CNT_IN_ALBUM_VIEW)
 
 
 def get_allow_track_count_in_album_entry(is_search_result: bool) -> bool:
@@ -795,8 +830,9 @@ def album_to_entry(
         album: Album,
         options: dict[str, any] = {}) -> dict[str, any]:
     is_search_result: bool = get_option(options=options, option_key=OptionKey.SEARCH_RESULT)
-    msgproc.log(f"album_to_entry for [{album.getId()}] SearchResult [{is_search_result}] ...")
+    # msgproc.log(f"album_to_entry for [{album.getId()}] SearchResult [{is_search_result}] ...")
     title: str = album.getTitle()
+    album_version: str = subsonic_util.get_album_version(album)
     # number of discs
     title = subsonic_util.append_number_of_discs_to_album_title(
         current_albumtitle=title,
@@ -811,7 +847,9 @@ def album_to_entry(
     title = subsonic_util.append_explicit_if_needed(title, album)
     append_artist: bool = (config.get_config_param_as_bool(
                            constants.ConfigParam.ALLOW_APPEND_ARTIST_IN_ALBUM_VIEW) and
-                           get_option(options=options, option_key=OptionKey.APPEND_ARTIST_IN_ALBUM_TITLE))
+                           get_option(options=options, option_key=OptionKey.APPEND_ARTIST_IN_ALBUM_TITLE)
+                           if not is_search_result
+                           else config.get_config_param_as_bool(constants.ConfigParam.ALLOW_APPEND_ARTIST_IN_SEARCH_RES))
     if append_artist:
         artist: str = album.getArtist()
         if artist:
@@ -822,12 +860,13 @@ def album_to_entry(
     append_year: bool = (config.get_config_param_as_bool(constants.ConfigParam.APPEND_YEAR_TO_ALBUM_SEARCH_RES)
                          if is_search_result
                          else config.get_config_param_as_bool(constants.ConfigParam.APPEND_YEAR_TO_ALBUM_VIEW))
-    msgproc.log(f"album_to_entry append_year [{append_year}]")
+    # msgproc.log(f"album_to_entry append_year [{append_year}]")
     if append_year and has_year(album):
         title = "{} [{}]".format(title, get_album_year_str(album))
     force_load: bool = get_option(options=options, option_key=OptionKey.FORCE_LOAD_QUALITY_BADGE)
     album_quality_badge: str = get_album_quality_badge(album=album, force_load=force_load)
-    msgproc.log(f"album_to_entry album_quality_badge for [{album.getId()}] is [{album_quality_badge}] force_load was [{force_load}]")
+    # msgproc.log(f"album_to_entry album_quality_badge for [{album.getId()}] is [{album_quality_badge}] "
+    #             f"force_load was [{force_load}]")
     if force_load and config.get_config_param_as_bool(constants.ConfigParam.APPEND_CODEC_TO_ALBUM):
         msgproc.log(f"album_to_entry for "
                     f"album_id: [{album.getId()}] "
@@ -845,9 +884,9 @@ def album_to_entry(
         blacklist_count: int = 0
         song: Song
         for song in song_list:
-            if not song.getSuffix() in codecs:
-                codecs.append(song.getSuffix())
-                if not song.getSuffix() in config.whitelist_codecs:
+            if not song.getSuffix().lower() in codecs:
+                codecs.append(song.getSuffix().lower())
+                if not song.getSuffix().lower() in config.whitelist_codecs:
                     blacklist_count += 1
                 else:
                     whitelist_count += 1
@@ -870,6 +909,11 @@ def album_to_entry(
         album_quality_badge=album_quality_badge,
         album_entry_type=constants.AlbumEntryType.ALBUM_VIEW,
         is_search_result=is_search_result)
+    title = subsonic_util.append_album_version_to_album_title(
+        current_albumtitle=title,
+        album_version=album_version,
+        album_entry_type=constants.AlbumEntryType.ALBUM_VIEW,
+        is_search_result=is_search_result)
     # show album id
     title = subsonic_util.append_album_id_to_album_title(
         current_albumtitle=title,
@@ -877,30 +921,31 @@ def album_to_entry(
         album_entry_type=constants.AlbumEntryType.ALBUM_VIEW,
         is_search_result=is_search_result)
     # musicbrainz?
-    mb_id: str = subsonic_util.get_album_musicbrainz_id(album)
-    msgproc.log(f"Found mb_id [{mb_id}] for album [{album.getId()}] [{album.getTitle()}] by [{album.getArtist()}]")
+    album_mbid: str = subsonic_util.get_album_musicbrainz_id(album)
+    msgproc.log(f"Found album_mbid [{album_mbid}] for album [{album.getId()}] [{album.getTitle()}] by [{album.getArtist()}]")
     show_mbid: bool = config.get_config_param_as_bool(
         constants.ConfigParam.SHOW_ALBUM_MBID_IN_ALBUM_SEARCH_RES
         if is_search_result
         else constants.ConfigParam.SHOW_ALBUM_MBID_IN_ALBUM_VIEW)
-    if mb_id and show_mbid:
+    if album_mbid and show_mbid:
         if config.get_config_param_as_bool(constants.ConfigParam.SHOW_ARTIST_MB_ID_AS_PLACEHOLDER):
             title = f"{title} [mb]"
         else:
-            title = f"{title} [{mb_id}]"
+            title = f"{title} [{album_mbid}]"
     artist = album.getArtist()
     cache_actions.on_album(album)
     identifier: ItemIdentifier = ItemIdentifier(ElementType.ALBUM.getName(), album.getId())
     id: str = identifier_util.create_objid(objid, identifier_util.create_id_from_identifier(identifier))
     entry: dict[str, any] = upmplgutils.direntry(id, objid, title=title, artist=artist)
-    cover_art_url: str = connector_provider.get().buildCoverArtUrl(album.getCoverArt())
+    # we save the cover art even if it's already there
+    cover_art_url: str = subsonic_util.build_cover_art_url(item_id=album.getCoverArt(), force_save=True)
     upnp_util.set_album_art_from_uri(cover_art_url, entry)
     upnp_util.set_album_id(album.getId(), entry)
     upnp_util.set_artist(artist=album.getArtist(), target=entry)
     upnp_util.set_date_from_album(album=album, target=entry)
     upnp_util.set_class_album(entry)
-    if album_quality_badge:
-        upnp_util.set_metadata("albumquality", album_quality_badge, entry)
+    upnp_util.set_upmpd_meta(upmpdmeta.UpMpdMeta.ALBUM_QUALITY, album_quality_badge, entry)
+    subsonic_util.set_album_metadata(album=album, target=entry)
     return entry
 
 
@@ -924,7 +969,7 @@ def album_id_to_album_focus(
         ElementType.ALBUM_FOCUS.getName(),
         album.getId())
     id: str = identifier_util.create_objid(objid, identifier_util.create_id_from_identifier(identifier))
-    art_uri = connector_provider.get().buildCoverArtUrl(item_id=album.getCoverArt())
+    art_uri = subsonic_util.build_cover_art_url(item_id=album.getCoverArt())
     entry = upmplgutils.direntry(id, objid, "Focus")
     upnp_util.set_album_art_from_uri(album_art_uri=art_uri, target=entry)
     return entry
@@ -971,6 +1016,6 @@ def album_version_to_entry(
     artist = current_album.getArtist()
     cache_actions.on_album(current_album)
     entry: dict[str, any] = upmplgutils.direntry(id, objid, title=title, artist=artist)
-    current_album_cover_art: str = connector_provider.get().buildCoverArtUrl(item_id=current_album.getCoverArt())
+    current_album_cover_art: str = subsonic_util.build_cover_art_url(item_id=current_album.getCoverArt())
     upnp_util.set_album_art_from_uri(current_album_cover_art, entry)
     return entry
