@@ -25,7 +25,7 @@ from uprclutils import audiomtypes, docfolder, uplog
 import uprclutils
 import uprclinit
 
-# Tags for which we may create auxiliary tag tables for facet descent. 
+# Tags for which we may create auxiliary tag tables for facet descent.
 #
 # The dict key is the tag name, used as container title in the tags tree,
 # except if an a different display value was set by the user
@@ -42,26 +42,24 @@ import uprclinit
 # This is the base set, with some custom translations (e.g. Group->cgroup). If a minimserver
 # configuration is used, Some entries may be filtered out and some may be added.
 _alltagtotable = {
-    'AlbumArtist' : 'albumartist',
-    'All Artists' : 'allartists',
-    'Artist' : 'artist', # Special processing in recolltosql: "albumartist" if set else "artist"
-    'Comment' : 'comment',
-    'Composer' : 'composer',
-    'Conductor' : 'conductor',
-    'Date' : 'date',
-    'Genre' : 'genre',
-    'Group' : 'cgroup', # can't have a table named group
-    'Label' : 'label',
-    'Lyricist' : 'lyricist',
-    'Orchestra' : 'orchestra',
-    'Performer' : 'performer',
-    }
+    "AlbumArtist": "albumartist",
+    "All Artists": "allartists",
+    "Artist": "artist",  # Special processing in recolltosql: "albumartist" if set else "artist"
+    "Comment": "comment",
+    "Composer": "composer",
+    "Conductor": "conductor",
+    "Date": "date",
+    "Genre": "genre",
+    "Group": "cgroup",  # can't have a table named group
+    "Label": "label",
+    "Lyricist": "lyricist",
+    "Orchestra": "orchestra",
+    "Performer": "performer",
+}
 
 # Translations used when fetching fields from the recoll record. Most have the same name as the
 # column.
-_coltorclfield = {
-    'allartists' : 'artist'
-    }
+_coltorclfield = {"allartists": "artist"}
 
 # The actual list of tags (e.g. "Genre", "Composer") which will be shown in the tree, after reading
 # the local configuration.
@@ -72,23 +70,31 @@ g_tagdisplaytag = {}
 # Same as _alltagtotable, filtered by g_indextags
 g_tagtotable = {}
 
+
 def getIndexTags():
     return g_indextags
+
+
 def getTagDisplayTag():
     return g_tagdisplaytag
+
+
 def getTagToTable():
     return g_tagtotable
 
+
 # Name of the join column for one of the tag tables. Actually, now that we use separate junction
 # tables instead of columns inside the tracks table, the column name could be constant. Kept it.
 def _clid(table):
-    return table + '_id'
+    return table + "_id"
+
+
 # Name of the junction table for a given tag table. Ex for genres.
 # rcldocs is not an sqlite table, it's the recoll document list.
 #         docidx        docidx                genre_id
 # rcldocs<------>tracks<------>tracks_genres<---------->genre
 def _junctb(table):
-    return "tracks_" + table  + "s"
+    return "tracks_" + table + "s"
 
 
 # Create an empty db.
@@ -96,7 +102,7 @@ def _junctb(table):
 # There is one table for each tag (Artist, Genre, Date, etc.), listing all possible values for the
 # particular tag. The table name is the value from the _alltagtotable array, <tagname> and it has 2
 # columns: <tagname>_id and value.
-# 
+#
 # The tracks table is the "main" table, and has a record for each track, with a title column, and an
 # album join column (album_id) (because a track can only belong to one album). The unique index into
 # this table is the document index in the recoll document list (docidx).
@@ -115,7 +121,7 @@ def _createsqdb(conn):
 
     # Create the albums table
     try:
-        c.execute('''DROP TABLE albums''')
+        c.execute("""DROP TABLE albums""")
     except:
         pass
     c.execute(
@@ -137,16 +143,17 @@ def _createsqdb(conn):
         # is a text version of all the artistid sets for each album track. If we were really
         # concerned about space usage, we could use a parallel temp table and drop it when done...
         "artists TEXT"
-        ")")
+        ")"
+    )
 
     # Create the main tracks table, which has a one-to-one relationship with the recoll document
     # array
     try:
-        c.execute('''DROP TABLE tracks''')
+        c.execute("""DROP TABLE tracks""")
     except:
         pass
-    tracksstmt = '''CREATE TABLE tracks 
-                     (docidx INT, album_id INT, trackno INT, title TEXT, path TEXT)'''
+    tracksstmt = """CREATE TABLE tracks 
+                     (docidx INT, album_id INT, trackno INT, title TEXT, path TEXT)"""
     c.execute(tracksstmt)
 
     # Create tables for tag values (e.g. all genre values, all composer values, etc.)
@@ -158,7 +165,7 @@ def _createsqdb(conn):
 def _createTagTables(cursor, tgnm):
     # Create a table for this tag values and value ids
     try:
-        cursor.execute('DROP TABLE ' + tgnm)
+        cursor.execute("DROP TABLE " + tgnm)
     except:
         pass
     stmt = "CREATE TABLE " + tgnm + " (" + _clid(tgnm) + " INTEGER PRIMARY KEY, value TEXT)"
@@ -169,12 +176,12 @@ def _createTagTables(cursor, tgnm):
     # remnant of the time where these columns were integral to the tracks table. Still, does not
     # hurt.
     try:
-        cursor.execute('DROP TABLE ' + _junctb(tgnm))
+        cursor.execute("DROP TABLE " + _junctb(tgnm))
     except:
         pass
     stmt = "CREATE TABLE " + _junctb(tgnm) + " (docidx INT, " + _clid(tgnm) + " INT)"
     cursor.execute(stmt)
-    
+
 
 # Augment indextag dict and create tables for a custom field, not part of our predefined set
 def _addCustomTable(conn, indextag):
@@ -194,24 +201,24 @@ def _prepareTags(conn):
     g_indextags = []
     g_tagdisplaytag = {}
     g_tagtotable = {}
-    
+
     indextagsp = uprclinit.g_minimconfig.getindextags()
     itemtags = uprclinit.g_minimconfig.getitemtags()
     if not indextagsp:
         # Our default list of index tags (showing up as containers in the tree). The second field in
         # each pair, if set, is the customized display (e.g. ("Composer", "Compositeur"))
-        indextagsp = [('Artist',''), ('Date',''), ('Genre',''), ('Composer','')]
+        indextagsp = [("Artist", ""), ("Date", ""), ("Genre", ""), ("Composer", "")]
 
     # Compute the actual list of index tags:
-    for v,d in indextagsp:
-        if v.lower() == 'none':
+    for v, d in indextagsp:
+        if v.lower() == "none":
             g_indextags = []
             g_tagdisplaytag = {}
             break
         g_indextags.append(v)
         g_tagdisplaytag[v] = d if d else v
     uplog("prepareTags: g_indextags: %s g_tagdisplaytag %s" % (g_indextags, g_tagdisplaytag))
-    
+
     # Compute an array of (table name, recoll field) translations for the tags we need to process,
     # as determined by the indexTags property. Most often they are identical. This also determines
     # what fields we create tables for.
@@ -239,7 +246,7 @@ def _prepareTags(conn):
 
 # Insert new value if not existing, return rowid of new or existing row
 def _auxtableinsert(conn, tb, value):
-    #uplog("_auxtableinsert [%s] -> [%s]" % (tb, value))
+    # uplog("_auxtableinsert [%s] -> [%s]" % (tb, value))
     c = conn.cursor()
     stmt = f"SELECT {_clid(tb)} FROM  {tb} WHERE value = ?"
     c.execute(stmt, (value,))
@@ -257,9 +264,9 @@ def _auxtableinsert(conn, tb, value):
 # should not arrive here, but let's play it safe.
 def _tracknofordoc(doc):
     try:
-        return int(doc["tracknumber"].split('/')[0])
+        return int(doc["tracknumber"].split("/")[0])
     except:
-        #uplog("_tracknofordoc: doc["tracknumber"] %s title %s url %s" %
+        # uplog("_tracknofordoc: doc["tracknumber"] %s title %s url %s" %
         #      (doc["tracknumber"], doc["title"], doc["url"]))
         return 1
 
@@ -271,21 +278,22 @@ _albtitdnumexp = re.compile(_albtitdnumre, flags=re.IGNORECASE)
 _folderdnumre = r"(cd|disc)[ ]*([0-9]+)(.*)"
 _folderdnumexp = re.compile(_folderdnumre, flags=re.IGNORECASE)
 
+
 # Create album record for track if needed (not already there).
 # The albums table is special, can't use auxtableinsert()
 def _maybecreatealbum(conn, doc):
     c = conn.cursor()
-    folder = docfolder(doc).decode('utf-8', errors = 'replace')
+    folder = docfolder(doc).decode("utf-8", errors="replace")
 
     album = doc["album"]
     if not album:
         album = uprclutils.basename(folder)
-        #uplog("Using %s for alb MIME %s title %s" % (album,doc["mtype"],doc["url"]))
+        # uplog("Using %s for alb MIME %s title %s" % (album,doc["mtype"],doc["url"]))
 
-    #uplog(f"_maybecreatealbum: album: [{album}] folder [{folder}]")
+    # uplog(f"_maybecreatealbum: album: [{album}] folder [{folder}]")
 
     if doc["albumartist"]:
-        albartist_id = _auxtableinsert(conn, 'artist', doc["albumartist"])
+        albartist_id = _auxtableinsert(conn, "artist", doc["albumartist"])
     else:
         albartist_id = None
 
@@ -295,7 +303,7 @@ def _maybecreatealbum(conn, doc):
     if doc["discnumber"]:
         try:
             discnum = int(doc["discnumber"])
-            #uplog(f"discnumber {discnum} folder {folder}")
+            # uplog(f"discnumber {discnum} folder {folder}")
         except:
             pass
 
@@ -305,42 +313,44 @@ def _maybecreatealbum(conn, doc):
     # differing titles)
     m = _albtitdnumexp.search(album)
     if m:
-        #uplog("Disc number found at end of album title")
-        for i in (3,4,5):
+        # uplog("Disc number found at end of album title")
+        for i in (3, 4, 5):
             if m.group(i):
                 adiscnum = int(m.group(i))
-                #uplog(f"Match is in group {i} adiscnum {adiscnum} discnum {discnum}")
+                # uplog(f"Match is in group {i} adiscnum {adiscnum} discnum {discnum}")
                 if not discnum:
                     discnum = adiscnum
                 if adiscnum == discnum:
                     album = m.group(1)
-                    #uplog(f"album title changed to [{album}]")
+                    # uplog(f"album title changed to [{album}]")
                 break
-            
+
     if not discnum:
         m = _folderdnumexp.search(uprclutils.basename(folder))
         if m:
             discnum = int(m.group(2))
-        
+
     # See if this albumdisc already exists (created for a previous track)
     stmt = "SELECT album_id, artist_id FROM albums WHERE albtitle = ? AND albfolder = ?"
     wcols = [album, folder]
     if discnum:
-        stmt += ' AND albtdisc = ?'
+        stmt += " AND albtdisc = ?"
         wcols.append(discnum)
-    #uplog(f"maybecreatealbum: {stmt} {wcols}")
+    # uplog(f"maybecreatealbum: {stmt} {wcols}")
     c.execute(stmt, wcols)
     r = c.fetchone()
     if r:
-        #uplog("maybecreatealbum: album found")
+        # uplog("maybecreatealbum: album found")
         album_id = r[0]
     else:
-        c.execute('''INSERT INTO 
+        c.execute(
+            """INSERT INTO 
         albums(albtitle, albfolder, artist_id, albdate, albtdisc, artists) 
-        VALUES (?,?,?,?,?,?)''',
-                  (album, folder, albartist_id, doc["date"], discnum, ""))
+        VALUES (?,?,?,?,?,?)""",
+            (album, folder, albartist_id, doc["date"], discnum, ""),
+        )
         album_id = c.lastrowid
-        #uplog(f"New album {album_id} {album} disc {discnum} artist {albartist_id} folder {folder}")
+        # uplog(f"New album {album_id} {album} disc {discnum} artist {albartist_id} folder {folder}")
 
     return album_id
 
@@ -355,28 +365,33 @@ def _updatealbartistlist(conn, album_id, rowids):
     stmt = f"UPDATE albums SET artists = artists || '|' || ? WHERE album_id = ?"
     values = (addstr, album_id)
     c.execute(stmt, values)
-        
+
 
 # Setting album covers needs to wait until we have scanned all tracks so that we can select
 # a consistant embedded art (first track in path order), as recoll scanning is in unsorted
 # directory order.
 def _setalbumcovers(conn, rcldocs):
     c = conn.cursor()
-    c.execute('''SELECT album_id,albtitle FROM albums''')
+    c.execute("""SELECT album_id,albtitle FROM albums""")
     for r in c:
         albid = r[0]
         albtitle = r[1]
         c1 = conn.cursor()
-        stmt = '''SELECT docidx FROM tracks WHERE album_id = ? ORDER BY path'''
-        c1.execute(stmt,  (albid,))
+        stmt = """SELECT docidx FROM tracks WHERE album_id = ? ORDER BY path"""
+        c1.execute(stmt, (albid,))
         for r1 in c1:
             docidx = r1[0]
             doc = rcldocs[docidx]
-            arturi = uprclutils.docarturi(doc, uprclinit.getHttphp(), uprclinit.getPathPrefix(),
-                                          preferfolder=True, albtitle=albtitle)
+            arturi = uprclutils.docarturi(
+                doc,
+                uprclinit.getHttphp(),
+                uprclinit.getPathPrefix(),
+                preferfolder=True,
+                albtitle=albtitle,
+            )
             if arturi:
                 cupd = conn.cursor()
-                #uplog(f"Setting albid {albid} albarturi to {arturi}")
+                # uplog(f"Setting albid {albid} albarturi to {arturi}")
                 cupd.execute("UPDATE albums SET albarturi = ?  WHERE album_id = ?", (arturi, albid))
                 break
 
@@ -401,14 +416,14 @@ def _setalbumartists(conn):
                 intersect = artsets[0]
                 for artset in artsets[1:]:
                     intersect = intersect.intersection(artset)
-                #uplog(f"_setalbumartists: INTERSECT for [{r[2]}]: {intersect}")
+                # uplog(f"_setalbumartists: INTERSECT for [{r[2]}]: {intersect}")
                 if intersect:
                     # if multiple values, have to chose one...
                     albumartist = [v for v in intersect][0]
-                    #uplog(f"Using albumartist {albumartist} for {r[2]}")
+                    # uplog(f"Using albumartist {albumartist} for {r[2]}")
 
         if albumartist == variousartistsid:
-            #uplog(f"Using albumartist Various Artists for {r[2]}")
+            # uplog(f"Using albumartist Various Artists for {r[2]}")
             pass
         c1 = conn.cursor()
         c1.execute("UPDATE albums SET artist_id = ? WHERE album_id = ?", (albumartist, r[0]))
@@ -418,9 +433,9 @@ def _setalbumartists(conn):
 def _albumstorecoll(conn, rcldb):
     c = conn.cursor()
     #                 0        1          2          3         4         5
-    stmt = '''SELECT album_id, albfolder, albtitle, albarturi, albdate, artist.value
+    stmt = """SELECT album_id, albfolder, albtitle, albarturi, albdate, artist.value
       FROM albums LEFT JOIN artist ON artist.artist_id = albums.artist_id
-      WHERE albtdisc is NULL'''
+      WHERE albtdisc is NULL"""
     c.execute(stmt, ())
     for r in c:
         udi = "albid" + str(r[0])
@@ -434,7 +449,7 @@ def _albumstorecoll(conn, rcldb):
         doc["url"] = "file://" + r[1]
         # uplog(f"_albumstorecoll: indexing album {doc['album']}")
         rcldb.addOrUpdate(udi, doc)
-    
+
 
 # Add artists to the recoll index so they can be searched for
 def _artiststorecoll(conn, rcldb):
@@ -447,10 +462,10 @@ def _artiststorecoll(conn, rcldb):
         doc = rcldb.doc()
         doc["title"] = r[1]
         doc["mtype"] = "inode/directory"
-        doc["url"] = "file://artists/" + r[1] # Not used ever
+        doc["url"] = "file://artists/" + r[1]  # Not used ever
         # uplog(f"_artiststorecoll: indexing artist {doc['title']}")
         rcldb.addOrUpdate(udi, doc)
-    
+
 
 # Check that the numbers are sequential
 def _checkseq(seq):
@@ -466,15 +481,15 @@ def _checkseq(seq):
 
 def _membertotopalbum(conn, memberalbid):
     c = conn.cursor()
-    c.execute('''SELECT * FROM albums WHERE album_id = ?''', (memberalbid,))
+    c.execute("""SELECT * FROM albums WHERE album_id = ?""", (memberalbid,))
     cols = [desc[0] for desc in c.description]
     # Get array of column values, and set primary key and albtdisc to
     # None before inserting the copy
-    tdiscindex = cols.index('albtdisc')
+    tdiscindex = cols.index("albtdisc")
     v = [e for e in c.fetchone()]
     v[0] = None
     v[tdiscindex] = None
-    c.execute('''INSERT INTO albums VALUES (%s)''' % ','.join('?'*len(v)),  v)
+    c.execute("""INSERT INTO albums VALUES (%s)""" % ",".join("?" * len(v)), v)
     return c.lastrowid
 
 
@@ -497,8 +512,10 @@ def _createmergedalbums(conn):
 
     # All candidates for merging: albums with a disc number not yet
     # merged (albalb is null)
-    c.execute('''SELECT album_id, albtitle, artist_id, albfolder FROM albums
-      WHERE albalb IS NULL AND albtdisc IS NOT NULL''')
+    c.execute(
+        """SELECT album_id, albtitle, artist_id, albfolder FROM albums
+      WHERE albalb IS NULL AND albtdisc IS NOT NULL"""
+    )
     c1 = conn.cursor()
     for r in c:
         albid = r[0]
@@ -508,32 +525,39 @@ def _createmergedalbums(conn):
         artist = r[2]
         folder = r[3]
 
-        #uplog(f"_createmergedalbums: albid {albid} artist_id {artist} albtitle {albtitle}")
+        # uplog(f"_createmergedalbums: albid {albid} artist_id {artist} albtitle {albtitle}")
 
         # Look for albums not already in a group, with the same title and artist
         if artist:
-            c1.execute('''SELECT album_id, albtdisc, albfolder FROM albums
+            c1.execute(
+                """SELECT album_id, albtdisc, albfolder FROM albums
                 WHERE albtitle = ? AND artist_id = ?
-                AND albalb is NULL AND albtdisc IS NOT NULL''',
-                       (albtitle, artist))
+                AND albalb is NULL AND albtdisc IS NOT NULL""",
+                (albtitle, artist),
+            )
         else:
-            c1.execute('''SELECT album_id, albtdisc, albfolder FROM albums
+            c1.execute(
+                """SELECT album_id, albtdisc, albfolder FROM albums
                 WHERE albtitle = ? AND artist_id IS NULL
-                AND albalb is NULL AND albtdisc IS NOT NULL''',
-                       (albtitle,))
+                AND albalb is NULL AND albtdisc IS NOT NULL""",
+                (albtitle,),
+            )
 
         rows = c1.fetchall()
         rows1 = _mergealbumsfilterfolders(folder, rows, 2)
 
-        #uplog(f"_createmergedalbums: got {len(rows1)} possible(s) title {albtitle}")
+        # uplog(f"_createmergedalbums: got {len(rows1)} possible(s) title {albtitle}")
 
         if len(rows1) > 1:
             albids = [row[0] for row in rows1]
             dnos = sorted([row[1] for row in rows1])
             if not _checkseq(dnos):
                 uplog(f"mergealbums: not merging bad seq {dnos} for albtitle {albtitle}")
-                c1.execute(f"UPDATE albums SET albtdisc = NULL " \
-                           f"WHERE album_id in ({','.join('?'*len(albids))})", albids)
+                c1.execute(
+                    f"UPDATE albums SET albtdisc = NULL "
+                    f"WHERE album_id in ({','.join('?'*len(albids))})",
+                    albids,
+                )
                 continue
 
             # Create record for whole album by copying the first
@@ -541,18 +565,22 @@ def _createmergedalbums(conn):
             topalbid = _membertotopalbum(conn, albids[0])
 
             # Update all album disc members with the top album id
-            values = [topalbid,] + albids
-            c1.execute(f"UPDATE albums SET albalb = ? " \
-                       f"WHERE album_id in ({','.join('?'*len(albids))})", values)
+            values = [
+                topalbid,
+            ] + albids
+            c1.execute(
+                f"UPDATE albums SET albalb = ? " f"WHERE album_id in ({','.join('?'*len(albids))})",
+                values,
+            )
             merged.update(albids)
-            #uplog("_createmergedalbums: merged: %s" % albids)
-            
+            # uplog("_createmergedalbums: merged: %s" % albids)
+
         elif len(rows1) == 1:
             # Album with a single disc having a discnumber. Just unset
             # the discnumber, we won't use it and its presence would
             # prevent the album from showing up. Alternatively we
             # could set albalb = album_id?
-            #uplog("Setting albtdisc to NULL albid %d" % albid)
+            # uplog("Setting albtdisc to NULL albid %d" % albid)
             c1.execute("UPDATE albums SET albtdisc = NULL WHERE album_id= ?", (albid,))
 
     # finally, set albalb to albid for all single-disc albums
@@ -567,10 +595,10 @@ def _createmergedalbums(conn):
 def parsedate(dt):
     if len(dt) > 10:
         dt = dt[0:10]
-    l = dt.split('-')
-    if len(l) > 3 or len(l) == 2 or len(l[0]) != 4 or l[0] == '0000':
+    l = dt.split("-")
+    if len(l) > 3 or len(l) == 2 or len(l[0]) != 4 or l[0] == "0000":
         return None
-    #uplog("parsedate: -> %s" % dt)
+    # uplog("parsedate: -> %s" % dt)
     return dt
 
 
@@ -581,7 +609,7 @@ def recolltosql(conn, rcldocs):
 
     _createsqdb(conn)
     tabtorclfield = _prepareTags(conn)
-    #uplog("Tagscreate: tabtorclfield: %s"%tabtorclfield)
+    # uplog("Tagscreate: tabtorclfield: %s"%tabtorclfield)
 
     maxcnt = 0
     totcnt = 0
@@ -591,7 +619,7 @@ def recolltosql(conn, rcldocs):
     # and no explicit AlbumArtist value. Set this as global, no need to query for it every time it's
     # needed.
     global variousartistsid
-    variousartistsid = _auxtableinsert(conn, "artist", "Various Artists")    
+    variousartistsid = _auxtableinsert(conn, "artist", "Various Artists")
 
     for docidx in range(len(rcldocs)):
         doc = rcldocs[docidx]
@@ -599,35 +627,38 @@ def recolltosql(conn, rcldocs):
 
         if totcnt % 1000 == 0:
             time.sleep(0)
-        
+
         # No need to include non-audio or non-tagged types
-        if doc["mtype"] not in audiomtypes or doc["mtype"] == 'inode/directory' \
-               or doc["mtype"] == 'audio/x-mpegurl':
+        if (
+            doc["mtype"] not in audiomtypes
+            or doc["mtype"] == "inode/directory"
+            or doc["mtype"] == "audio/x-mpegurl"
+        ):
             continue
 
         # Album creation ?
         album_id = _maybecreatealbum(conn, doc)
-        
+
         trackno = _tracknofordoc(doc)
 
-        if doc["url"].find('file://') == 0:
+        if doc["url"].find("file://") == 0:
             path = doc["url"][7:]
         else:
-            path = ''
+            path = ""
 
-        # Misc tag values:            
+        # Misc tag values:
         # Set base values for column names, values list, placeholders. Done this way because we used
         # to add to the lists for the tag values (which now use separate junction tables).
-        columns = ['docidx','album_id','trackno','title',      'path']
-        values =  [ docidx,  album_id,  trackno,  doc["title"], path]
-        placehold = ['?',    '?',       '?',      '?',          '?']
+        columns = ["docidx", "album_id", "trackno", "title", "path"]
+        values = [docidx, album_id, trackno, doc["title"], path]
+        placehold = ["?", "?", "?", "?", "?"]
         for tb, rclfld in tabtorclfield:
             value = doc[rclfld]
             # Special processing for some fields
-            if rclfld == 'date':
+            if rclfld == "date":
                 # See comment in parsedate
                 if not value:
-                    value = doc['dmtime']
+                    value = doc["dmtime"]
                 if value:
                     value = parsedate(value)
             elif rclfld == "artist":
@@ -648,7 +679,7 @@ def recolltosql(conn, rcldocs):
                 jvals = [docidx, rowid]
                 # uplog(f"EXECUTING {stmt} values {jvals}")
                 c.execute(stmt, jvals)
-            if tb == 'artist' and rowids:
+            if tb == "artist" and rowids:
                 _updatealbartistlist(conn, album_id, rowids)
         # Create the main record in the tracks table.
         stmt = "INSERT INTO tracks(" + ",".join(columns) + ") VALUES(" + ",".join(placehold) + ")"
@@ -665,4 +696,3 @@ def recolltosql(conn, rcldocs):
     _albumstorecoll(conn, rcldb)
     _artiststorecoll(conn, rcldb)
     uplog(f"recolltosql: processed {totcnt} docs in {end-start:.1f} Seconds")
- 
